@@ -22,10 +22,10 @@
 #include "kservicegroupfactory_p.h"
 #include "kservice.h"
 #include "ksycoca_p.h"
+#include "servicesdebug.h"
 #include <ksycoca.h>
 #include <kdesktopfile.h>
 #include <kconfiggroup.h>
-#include <QDebug>
 
 KServiceGroup::KServiceGroup(const QString &name)
     : KSycocaEntry(*new KServiceGroupPrivate(name))
@@ -60,7 +60,6 @@ void KServiceGroupPrivate::load(const QString &cfg)
     m_bNoDisplay = desktopFile.noDisplay();
     m_strBaseGroupName = config.readEntry("X-KDE-BaseGroup");
     suppressGenericNames = config.readEntry("X-KDE-SuppressGenericNames", QStringList());
-//  d->sortOrder = config.readEntry("SortOrder", QStringList());
 
     // Fill in defaults.
     if (m_strCaption.isEmpty()) {
@@ -74,7 +73,7 @@ void KServiceGroupPrivate::load(const QString &cfg)
         }
     }
     if (m_strIcon.isEmpty()) {
-        m_strIcon = QString::fromLatin1("folder");
+        m_strIcon = QStringLiteral("folder");
     }
 }
 
@@ -368,7 +367,7 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
         grp = KSycocaPrivate::self()->serviceGroupFactory()->findGroupByDesktopPath(path, true);
 
         group = grp.data();
-        if (0 == group) { // No guarantee that we still exist!
+        if (nullptr == group) { // No guarantee that we still exist!
             return KServiceGroup::List();
         }
     }
@@ -428,9 +427,9 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
     }
 
     if (sortOrder.isEmpty()) {
-        sortOrder << QString::fromLatin1(":M");
-        sortOrder << QString::fromLatin1(":F");
-        sortOrder << QString::fromLatin1(":OIH IL[4]"); //just inline header
+        sortOrder << QStringLiteral(":M");
+        sortOrder << QStringLiteral(":F");
+        sortOrder << QStringLiteral(":OIH IL[4]"); //just inline header
     }
 
     QString rp = path;
@@ -487,7 +486,7 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
             } else if (item.contains(QLatin1String(":O"))) {
                 //todo parse attribute:
                 QString tmp(item);
-                tmp = tmp.remove(QLatin1String(":O"));
+                tmp = tmp.remove(QStringLiteral(":O"));
                 QStringList optionAttribute = tmp.split(QLatin1Char(' '), QString::SkipEmptyParts);
                 if (optionAttribute.isEmpty()) {
                     optionAttribute.append(tmp);
@@ -566,7 +565,7 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
 
                         if (nextItem.startsWith(QLatin1String(":O"))) {
                             QString tmp(nextItem);
-                            tmp = tmp.remove(QLatin1String(":O"));
+                            tmp = tmp.remove(QStringLiteral(":O"));
                             QStringList optionAttribute = tmp.split(QLatin1Char(' '), QString::SkipEmptyParts);
                             if (optionAttribute.isEmpty()) {
                                 optionAttribute.append(tmp);
@@ -633,7 +632,7 @@ void KServiceGroupPrivate::parseAttribute(const QString &item,  bool &showEmptyM
         showInlineAlias = false;
     } else if ((item).contains(QLatin1String("IL"))) { //inline limite!
         QString tmp(item);
-        tmp = tmp.remove(QLatin1String("IL["));
+        tmp = tmp.remove(QStringLiteral("IL["));
         tmp = tmp.remove(QLatin1Char(']'));
         bool ok;
         int _inlineValue = tmp.toInt(&ok);
@@ -642,7 +641,7 @@ void KServiceGroupPrivate::parseAttribute(const QString &item,  bool &showEmptyM
         }
         inlineValue =  _inlineValue;
     } else {
-        qDebug() << "This attribute is not supported:" << item;
+        qCDebug(SERVICES) << "This attribute is not supported:" << item;
     }
 }
 
@@ -662,7 +661,7 @@ KServiceGroup::Ptr
 KServiceGroup::root()
 {
     KSycoca::self()->ensureCacheValid();
-    return KSycocaPrivate::self()->serviceGroupFactory()->findGroupByDesktopPath(QString::fromLatin1("/"), true);
+    return KSycocaPrivate::self()->serviceGroupFactory()->findGroupByDesktopPath(QStringLiteral("/"), true);
 }
 
 KServiceGroup::Ptr
@@ -679,7 +678,7 @@ KServiceGroup::Ptr
 KServiceGroup::childGroup(const QString &parent)
 {
     KSycoca::self()->ensureCacheValid();
-    return KSycocaPrivate::self()->serviceGroupFactory()->findGroupByDesktopPath(QString::fromLatin1("#parent#") + parent, true);
+    return KSycocaPrivate::self()->serviceGroupFactory()->findGroupByDesktopPath(QLatin1String("#parent#") + parent, true);
 }
 
 QString KServiceGroup::baseGroupName() const
@@ -704,7 +703,7 @@ public:
     {
     }
 
-    virtual QString name() const;
+    QString name() const override;
 };
 
 QString KServiceSeparatorPrivate::name() const
